@@ -2,7 +2,7 @@
 use strict;
 use AnyEvent::FriendFeed::Realtime;
 
-my($user, $remote_key, $method) = @ARGV;
+my($user, $remote_key, $request) = @ARGV;
 my $done = AnyEvent->condvar;
 
 binmode STDOUT, ":utf8";
@@ -10,10 +10,10 @@ binmode STDOUT, ":utf8";
 my $client = AnyEvent::FriendFeed::Realtime->new(
     username   => $user,
     remote_key => $remote_key,
-    method     => $method || "home",
+    request    => $request || "/feed/home",
     on_entry   => sub {
         my $entry = shift;
-        print "$entry->{user}{name}: $entry->{title}\n";
+        print "$entry->{from}{name}: $entry->{body}\n";
     },
     on_error   => sub {
         warn "ERROR: $_[0]";
